@@ -966,6 +966,10 @@ rxUiGet.foceiEtaNames <- function(x, ...) {
     .len0 <- length(env$model$inner$state)
     .len2 <- .len0 - .len
     if (.len2 > 0) {
+      .env <- .nlmixrEvalEnv$envir
+      if (!is.environment(.env)) {
+        .env <- parent.frame(1)
+      }
       .rxControl <- rxode2::rxGetControl(ui, "rxControl", rxode2::rxControl())
       rxode2::rxAssignControlValue(ui, "rxControl", rxode2::rxControlUpdateSens(.rxControl, .len2, .len0))
     }
@@ -990,6 +994,10 @@ rxUiGet.foceiEtaNames <- function(x, ...) {
       }
     }, integer(1), USE.NAMES=FALSE))
     if (.maxLl > 0) {
+      .env <- .nlmixrEvalEnv$envir
+      if (!is.environment(.env)) {
+        .env <- parent.frame(1)
+      }
       .rxControl <- rxode2::rxGetControl(ui, "rxControl", rxode2::rxControl())
       .rxControl$nLlikAlloc <- .maxLl
       rxode2::rxAssignControlValue(ui, "rxControl", .rxControl)
@@ -1141,6 +1149,24 @@ rxUiGet.foceiEtaNames <- function(x, ...) {
   env$scaleC <- .scaleC
 }
 
+#' @export
+rxUiGet.scaleCtheta <- function(x, ...) {
+  .ui <- x[[1]]
+  .env <- new.env(parent=emptyenv())
+  .env$lower <- .ui$iniDf[!is.na(.ui$iniDf$ntheta), "lower"]
+  .foceiOptEnvSetupScaleC(.ui, .env)
+  .env$scaleC[!.ui$iniDf$fix]
+}
+
+#' @export
+rxUiGet.scaleCnls <- function(x, ...) {
+  .ui <- x[[1]]
+  .env <- new.env(parent=emptyenv())
+  .env$lower <- .ui$iniDf[!is.na(.ui$iniDf$ntheta), "lower"]
+  .foceiOptEnvSetupScaleC(.ui, .env)
+  .env$scaleC[!.ui$iniDf$fix & !(.ui$iniDf$err %in% c("add", "prop", "pow"))]
+}
+
 #' This sets up the transformation bounds and indexes and bounds for inner.cpp
 #'
 #' Note that the C code assumes the index starts at 1
@@ -1284,11 +1310,19 @@ attr(rxUiGet.foceiOptEnv, "desc") <- "Get focei optimization environment"
 #' @param data Input dataset
 #' @param env focei environment where focei family is run
 #' @param ui rxode2 ui
+#' @param rxControl is the rxode2 control that is used to translate to the modeling dataset
 #' @return Nothing, called for side effects
 #' @author Matthew L. Fidler
 #' @keywords internal
 #' @export
-.foceiPreProcessData <- function(data, env, ui) {
+.foceiPreProcessData <- function(data, env, ui, rxControl=NULL) {
+  if (is.null(rxControl)) {
+    .env <- .nlmixrEvalEnv$envir
+    if (!is.environment(.env)) {
+      .env <- parent.frame(1)
+    }
+    rxControl <- rxControl()
+  }
   env$origData <- as.data.frame(data)
   data <- env$origData
   .covNames <- ui$covariates
@@ -1300,6 +1334,7 @@ attr(rxUiGet.foceiOptEnv, "desc") <- "Get focei optimization environment"
     }
   }, character(1))
   requiredCols <- c("ID", "DV", "TIME", .covNames)
+  if (is.null(data$ID)) data$ID <- 1L
   checkmate::assert_names(names(data), must.include = requiredCols)
   if (is.null(data$EVID)) data$EVID <- 0
   if (is.null(data$AMT)) data$AMT <- 0
@@ -1320,10 +1355,14 @@ attr(rxUiGet.foceiOptEnv, "desc") <- "Get focei optimization environment"
   }
   data$nlmixrRowNums <- seq_len(nrow(data))
   .keep <- unique(c("nlmixrRowNums", env$table$keep))
-  .et <- rxode2::etTrans(inData=data, obj=ui$mv0,
+  .mod <- rxode2::rxModelVars(paste0(ui$mv0$model["normModel"], "\n", .foceiToCmtLinesAndDvid(ui)))
+  .et <- rxode2::etTrans(inData=data, obj=.mod,
                          addCmt=TRUE, dropUnits=TRUE,
                          keep=unique(c("nlmixrRowNums", env$table$keep)),
-                         allTimeVar=TRUE, keepDosingOnly=FALSE)
+                         allTimeVar=TRUE, keepDosingOnly=FALSE,
+                         addlKeepsCov = rxControl$addlKeepsCov,
+                         addlDropSs = rxControl$addlDropSs,
+                         ssAtDoseTime = rxControl$ssAtDoseTime)
   .lst <- attr(class(.et), ".rxode2.lst")
   .keepL <- .lst$keepL[[1]]
   .idLvl <- .lst$idLvl
@@ -1531,6 +1570,19 @@ attr(rxUiGet.foceiOptEnv, "desc") <- "Get focei optimization environment"
           deparse1(ui$dvidLine)),
         collapse="\n")
 }
+#' Calculate the parameter history
+#'
+#' @param .ret return data
+#' @return parameter history data frame
+#' @noRd
+#' @author Matthew L. Fidler
+.parHistCalc <- function(.ret) {
+  .tmp <- .ret$parHistData
+  .tmp <- .tmp[.tmp$type == "Unscaled", names(.tmp) != "type"]
+  .iter <- .tmp$iter
+  .tmp <- .tmp[, names(.tmp) != "iter"]
+  data.frame(iter = .iter, .tmp, check.names=FALSE)
+}
 
 #' Setup the par history information
 #'
@@ -1540,13 +1592,7 @@ attr(rxUiGet.foceiOptEnv, "desc") <- "Get focei optimization environment"
 #' @noRd
 .foceiSetupParHistData <- function(.ret) {
   if (exists("parHistData", envir=.ret)) {
-    .tmp <- .ret$parHistData
-    .tmp <- .tmp[.tmp$type == "Unscaled", names(.tmp) != "type"]
-    .iter <- .tmp$iter
-    .tmp <- .tmp[, names(.tmp) != "iter"]
-    ## .ret$parHistStacked <- data.frame(stack(.tmp), iter = .iter)
-    ## names(.ret$parHistStacked) <- c("val", "par", "iter")
-    .ret$parHist <- data.frame(iter = .iter, .tmp)
+    .ret$parHist <- .parHistCalc(.ret)
   }
 }
 
@@ -1556,7 +1602,7 @@ attr(rxUiGet.foceiOptEnv, "desc") <- "Get focei optimization environment"
   .env <- ui$foceiOptEnv
   .env$table <- env$table
   .data <- env$data
-  .foceiPreProcessData(.data, .env, ui)
+  .foceiPreProcessData(.data, .env, ui, .control$rxControl)
   if (!is.null(.env$cov)) {
     checkmate::assertMatrix(.env$cov, any.missing=FALSE, min.rows=1, .var.name="env$cov",
                             row.names="strict", col.names="strict")
@@ -1599,8 +1645,13 @@ attr(rxUiGet.foceiOptEnv, "desc") <- "Get focei optimization environment"
   nmObjHandleControlObject(get("control", envir=.ret), .ret)
   assignInMyNamespace(".currentTimingEnvironment", .ret) # add environment for updating timing info
   if (.control$calcTables) {
-    .ret <- addTable(.ret, updateObject="no", keep=.ret$table$keep, drop=.ret$table$drop,
-                     table=.ret$table)
+    .tmp <- try(addTable(.ret, updateObject="no", keep=.ret$table$keep, drop=.ret$table$drop,
+                         table=.ret$table), silent=TRUE)
+    if (inherits(.tmp, "try-error")) {
+      warning("error calculating tables, returning without table step", call.=FALSE)
+    } else {
+      .ret <- .tmp
+    }
   }
   nlmixrWithTiming("compress", {
     if (exists("saem", .env)) {
@@ -1616,7 +1667,7 @@ attr(rxUiGet.foceiOptEnv, "desc") <- "Get focei optimization environment"
       .env$saem0 <- .saem
     }
     if (.control$compress) {
-      for (.item in c("origData", "phiM", "parHist", "saem0")) {
+      for (.item in c("origData", "phiM", "parHistData", "saem0")) {
         if (exists(.item, .env)) {
           .obj <- get(.item, envir=.env)
           .size <- utils::object.size(.obj)
@@ -1638,7 +1689,7 @@ attr(rxUiGet.foceiOptEnv, "desc") <- "Get focei optimization environment"
                     "xType", "IDlabel", "ODEmodel",
                     # times
                     "optimTime", "setupTime", "covTime",
-                    "parHistData", "dataSav", "idLvl", "theta",
+                    "parHist", "dataSav", "idLvl", "theta",
                     "missingTable", "missingControl", "missingEst")) {
       if (exists(.item, .env)) {
         rm(list=.item, envir=.env)
