@@ -36,52 +36,82 @@
     ret$popDfSig <- data.frame(Parameter = .lab, ret$popDfSig, check.names = FALSE)
   }
 }
+#' Apply the manual translation for only one item
+#'
+#' @param i Which parameter should be updated
+#' @param .ret return environment
+#' @param .ui user interface function
+#' @param .qn The qn for the
+#' @param .btName Back-transform name
+#' @param .fmt format for one estimate
+#' @param .fmt2 format for estimate and ci
+#' @return nothing, called for side effects
+#' @keywords internal
+#' @author Matthew L. Fidler
+#' @noRd
+.updateParFixedApplyManualBacktransformationsI <- function(i, .ret, .ui,
+                                                           .qn, .btName,
+                                                           .fmt, .fmt2) {
+  theta <- row.names(.ret$popDf)[i]
+  .w <- which(.ui$iniDf$name == theta)
+  if (length(.w) == 1L) {
+    .b <- .ui$iniDf$backTransform[.w]
+    if (!is.na(.b)) {
+      .bfun <- try(get(.b, envir=.nlmixrEvalEnv$envir, mode="function"), silent=TRUE)
+      if (inherits(.bfun, "try-error")) {
+        warning("unknown function '", .b, "' for manual backtransform, revert to nlmixr2 back-transformation detection for, '", theta, "'",
+                call.=FALSE)
+        return(invisible())
+      }
+      .est <- .ret$popDf$Estimate[i]
+      .se <- .ret$popDf$SE[i]
+      .bt <- .ret$popDf[["Back-transformed"]]
+      .bt[i] <- .bfun(.est)
+      .ret$popDf[["Back-transformed"]] <- .bt
+      if (!is.na(.se)) {
+        .i1 <- .ret$popDf[["CI Lower"]]
+        .low <- .bfun(.est - .se * .qn)
+        .i1[i] <- .low
+        .ret$popDf[["CI Lower"]] <- .i1
+        .i1 <- .ret$popDf[["CI Upper"]]
+        .hi <- .bfun(.est + .se * .qn)
+        .i1[i] <- .hi
+        .ret$popDf[["CI Upper"]] <- .i1
+        .bt2 <- .ret$popDfSig[[.btName]]
+        .bt2[i] <- sprintf(.fmt, .bfun(.est),
+                           .low, .hi)
+        .ret$popDfSig[[.btName]] <- .bt2
+      } else {
+        .bt2 <- .ret$popDfSig[[.btName]]
+        .bt2[i] <- sprintf(.fmt2, .bfun(.est))
+        .ret$popDfSig[[.btName]] <- .bt2
+      }
+    }
+  }
+}
+
 #'  This applies the manually specified back-transformations
 #'
 #' @param .ret focei environment
-#' @return Nothing, called for side effecs
+#' @return Nothing, called for side effects
 #' @author Matthew L. Fidler
 #' @noRd
 .updateParFixedApplyManualBacktransformations <- function(.ret, .ui) {
-  .qn <- qnorm(1.0-(1-0.95)/2)
-  .btName <- names(.ret$popDfSig)[4]
+  .qn <- qnorm(1.0-(1-.ret$control$ci)/2)
+  .n <- names(.ret$popDfSig)
+  if (length(.n) >= 4) {
+    .btName <- names(.ret$popDfSig)[4]
+  } else if (length(.n) >= 2) {
+    .btName <- names(.ret$popDfSig)[2]
+  } else {
+    return(NULL)
+  }
   .sigdig <- rxode2::rxGetControl(.ui, "sigdig", 3L)
   .fmt <- paste0("%", .sigdig, "g (%", .sigdig, "g, %", .sigdig, "g)")
   .fmt2 <- paste0("%", .sigdig, "g")
-  lapply(seq_along(.ret$popDf$Estimate), function(i) {
-    theta <- row.names(.ret$popDf)[i]
-    .w <- which(.ui$iniDf$name == theta)
-    if (length(.w) == 1L) {
-      .b <- .ui$iniDf$backTransform[.w]
-      if (!is.na(.b)) {
-        .est <- .ret$popDf$Estimate[i]
-        .se <- .ret$popDf$SE[i]
-        .bt <- .ret$popDf[["Back-transformed"]]
-        .bt[i] <- get(.b, envir=globalenv())(.est)
-        .ret$popDf[["Back-transformed"]] <- .bt
-        if (is.na(.se)) {
-          .i1 <- .ret$popDf[["CI Lower"]]
-          .low <- get(.b, envir=globalenv())(.est - .se * .qn)
-          .i1[i] <- .low
-          .ret$popDf[["CI Lower"]] <- .i1
-          .i1 <- .ret$popDf[["CI Upper"]]
-          .hi <- get(.b, envir=globalenv())(.est + .se * .qn)
-          .i1[i] <- .hi
-          .ret$popDf[["CI Upper"]] <- .i1
-          .bt2 <- .ret$popDfSig[[.btName]]
-          .bt2[i] <- sprintf(.fmt, .est, .low, .hi)
-          .ret$popDfSig[[.btName]] <- .bt2
-        } else {
-          .bt2 <- .ret$popDfSig[[.btName]]
-          .bt2[i] <- sprintf(.fmt, .est, .low, .hi)
-          .ret$popDfSig[[.btName]] <- .bt2
-          .bt2 <- .ret$popDfSig[[.btName]]
-          .bt2[i] <- sprintf(.fmt2, .est)
-          .ret$popDfSig[[.btName]] <- .bt2
-        }
-      }
-    }
-  })
+  lapply(seq_along(.ret$popDf$Estimate), .updateParFixedApplyManualBacktransformationsI,
+         .ret=.ret, .ui=.ui, .qn=.qn, .btName=.btName,
+         .fmt=.fmt, .fmt2=.fmt2)
 }
 
 #' This gets the CV/SD for a single ETA
@@ -91,36 +121,41 @@
 #' @param .env Environment where the indicators of `.sdOnly`, `.cvOnly` are stored so the column name can be changed to match the data
 #' @param .ome Omega fixed vector
 #' @param .muRefCurEval The current mu ref evaluation.  This determines if the ETA is logit normal and %CV should be calculated.
-#' @param .sigdig is the number of significant digits used in the evaulation
-#' @return Data frame row with ch= the charaacter representation and v is the vector representation of the CV or sd
-#' @author Matthew L. Fidler
+#' @param .sigdig is the number of significant digits used in the evaluation
+#' @return Data frame row with ch= the character representation and v is the vector representation of the CV or sd
+#' @author Matthew L. Fidler and Bill Denney
 #' @noRd
 .updateParFixedGetEtaRow <- function(.eta, .env, .ome, .omegaFix, .muRefCurEval, .sigdig) {
   .v <- .ome[.eta, .eta]
   .w <- which(.muRefCurEval$parameter == .eta)
   if (.muRefCurEval$curEval[.w] == "exp") {
     assign(".sdOnly", FALSE, envir=.env)
-    return(data.frame(
-      ch = paste0(
-        ifelse(.omegaFix[.eta], "fix(", ""),
-        formatC(signif(sqrt(exp(.v) - 1) * 100, digits = .sigdig),
-                digits = .sigdig, format = "fg", flag = "#"),
-        ifelse(.omegaFix[.eta], ")", "")
-      ),
-      v = sqrt(exp(.v) - 1) * 100))
+    .valNumber <- sqrt(exp(.v) - 1) * 100
+    .valCharPrep <- .valNumber
   } else {
     assign(".cvOnly", FALSE, envir=.env)
-    return(data.frame(
-      ch = paste0(
-        ifelse(.omegaFix[.eta], "fix(", ""),
-        formatC(signif(sqrt(.v), digits = .sigdig),
-                digits = .sigdig, format = "fg", flag = "#"),
-        ifelse(.omegaFix[.eta], ")", "")),
-      v = .v))
+    .valNumber <- .v
+    .valCharPrep <- sqrt(.v)
   }
+  if (.omegaFix[.eta]) {
+    .charPrefix <- "fix("
+    .charSuffix <- ")"
+  } else {
+    .charPrefix <- ""
+    .charSuffix <- ""
+  }
+  .valChar <-
+    formatC(
+      signif(.valCharPrep, digits = .sigdig),
+      digits = .sigdig, format = "fg", flag = "#"
+    )
+  data.frame(
+    ch = paste0(.charPrefix, .valChar, .charSuffix),
+    v = .valNumber
+  )
 }
 
-#'  This will add the between subject varaibility to the mu-referenced theta.  It also expands the table to include non-mu referenced ETAs
+#'  This will add the between subject variability to the mu-referenced theta.  It also expands the table to include non-mu referenced ETAs
 #'
 #'
 #' @param .ret The focei return environment
@@ -302,6 +337,7 @@
 
 #' @export
 `$.nlmixr2FitCore` <- function(obj, arg, exact = FALSE) {
+  rxode2parse::.udfEnvSet(parent.frame(1))
   .env <- obj
   .arg <- .nmObjBackward[arg]
   if (is.na(.arg)) .arg <- arg
@@ -311,11 +347,12 @@
   if (!is.null(.ret)) return(.ret)
 }
 
- #' @export
+#' @export
 `$.nlmixr2FitCoreSilent` <- `$.nlmixr2FitCore`
 
 #' @export
 `$.nlmixr2FitData` <- function(obj, arg, exact = FALSE) {
+  rxode2parse::.udfEnvSet(parent.frame(1))
   .ret <- obj[[arg]]
   if (arg == "md5") {
     return(.nlmixr2Md5(obj))
